montepy.data\_inputs.thermal\_scattering module
===============================================


.. automodule:: montepy.data_inputs.thermal_scattering
   :members:
   :undoc-members:
   :show-inheritance:
